©Journal of Sports Science and Medicine (2015) **14,** 698-701
<http://www.jssm.org>

**Research article**

# **Assessing Stride Variables and Vertical Stiffness with GPS-Embedded Accel-** **erometers: Preliminary Insights for the Monitoring of Neuromuscular Fatigue** **on the Field**

**Martin Buchheit** **\[1,2,3\]**  **, Andrew Gray** **\[4,5\]** **and Jean-Benoit Morin** **\[6\]**
**1** Sport Science Department, Myorobie Association, Montvalezan, France; **2** Performance Department, Paris SaintGermain Football Club, Saint-Germain-en-Laye, France; **\[3 \]** Institute of Sport, Exercise and Active Living, College of
Sport and Exercise Science, Victoria University, Melbourne, Australia; **\[4\]** Athletic Data Innovations, Sydney, Australia;
**5** Cronulla Sharks Rugby League Football Club, Australia; **6** Laboratoire Motricité Humaine Education Sport Santé,
Université de Nice Sophia Antipolis, Nice, France.

**Abstract**
The aim of the present study was to examine the ability of a
GPS-imbedded accelerometer to assess stride variables and

vertical stiffness (K), which are directly related to neuromuscular fatigue during field-based high-intensity runs. The ability to
detect stride imbalances was also examined. A team sport player
performed a series of 30-s runs on an instrumented treadmill (6
runs at 10, 17 and 24 km∙h \[-1\] ) with or without his right ankle
taped (aimed at creating a stride imbalance), while wearing on
his back a commercially-available GPS unit with an embedded
100-Hz tri-axial accelerometer. Contact (CT) and flying (FT)
time, and K were computed from both treadmill and accelerometers (Athletic Data Innovations) data. The agreement
between treadmill (criterion measure) and accelerometer-derived
data was examined. We also compared the ability of the different systems to detect the stride imbalance. Biases were small
(CT and K) and moderate (FT). The typical error of the estimate
was trivial (CT), small (K) and moderate (FT), with nearly
perfect (CT and K) and large (FT) correlations for treadmill vs.
accelerometer. The tape induced very large increase in the right

- left foot ∆ in CT, FT and K measured by the treadmill. The
  tape effect on CT and K ∆ measured with the accelerometers
  were also very large, but of lower magnitude than with the
  treadmill. The tape effect on accelerometer-derived ∆ FT was
  unclear. Present data highlight the potential of a GPS-embedded
  accelerometer to assess CT and K during ground running.

**Key words:** Movement tracking, fatigue monitoring

**Introduction**

Monitoring acute neuromuscular fatigue is important for
all run-based sports, and has various implications including training load management to prevent injuries and/or
rotation/substitution strategies during matches. The ability
to assess running strides asymmetries, and in turn, possible lower-limb muscle strength imbalances can also provide important information with respect to injury risk,
during both normal and rehabilitation training (Fousekis,
Tsepis et al., 2011). Classical time-motion analyses in
team-sports, which include distance covered into specific
speed (Carling, 2013), acceleration and deceleration
(Aughey, 2011) zones, and accelerometer-derived
measures of overall ‘body load’ (Barrett et al., 2014), are
unfortunately largely dependent on match pace and might

therefore lack of sensitivity to detect neuromuscular fatigue per se. It is actually well understood today that running activity during matches is more related to match
tactics and score line than fatigue or fitness per se (Carling, 2013).

Recent results have nevertheless suggested that
micro-sensors, such as the accelerometers included in the
GPS units worn by the majority of team sport players
(i.e., GPS-imbedded accelerometers) may provide, in
comparison with classical locomotor-related data, more
fatigue-sensitive measures. For example, in fatigued elite
Australian Rules footballers showing at least an 8% decreased flight time: contraction time ratio from a countermovement jump, there was a reduction in the contribution of the vertical axis to the total accelerometer load

during matches (Cormack et al., 2013). Unfortunately, the
actual meaning of the vertical axis loading remains partially unclear, since it doesn’t represent a clear biomechanical/locomotor entity. Possibly more promising accelerometer-derived measures may include contact time
(CT) and vertical stiffness (K) (Gaudino et al., 2013),
which are common stride variables, and have been shown
to be largely affected by acute neuromuscular fatigue
during repeated high-intensity runs (Morin et al., 2006,
Girard et al., 2011). However, the validity of accelerometer-derived CT, flying time (FT) and K have not been
examined yet. Whether accelerometer-derived data can
also accurately detect stride asymmetries is also, to our
knowledge, still unclear.

The aims of the present study were to examine the
ability of GPS-imbedded accelerometers 1) to assess
stride variables and vertical stiffness and 2) to detect
stride asymmetries during running.

**Methods**

**Participant and design**
Using a single-subject design protocol, a 36-y old team
sport player (1.82 m, 80 kg) performed a series of 30-s
runs at a 1% incline on a motorized instrumented tread
mill (ADAL3D-WR, MD, HEF Tecmachine, AndrézieuxBoutheon, France): 2 sets of 3 runs at 10 km∙h \[-1\], 6 at 17
km/h and 6 at 24 km∙h \[-1\] ) with or without his right ankle
taped (aimed at slightly shortening/stiffening the Achilles
tendon and in turn, creating a stride imbalance, Figure 1).

Received: 08 April 2015 / Accepted: 26 July 2015 / Published (online): 24 November 2015

Buchheit et al.

The player was highly familiar with treadmill running,
and had no history of lower-limb injury. Tapping the right
side was an arbitrary choice. Given the fact that the player
had no history of previous injury, there is no reason to
think that the side of the taping would have influenced the
outcome of the present study. There was a 45-s rest between each trial to minimize fatigue, and a 3-min break
between each set. The duration of each set was therefore

~11-min long. At the end of each run, the player stopped
running immediately and placed his feet on each side of
the belt while holding the handlebars, before re-loading
the treadmill at the end of each rest; the treadmill was
never stopped so that the speed could be adjusted for the
next run. The order of each run was randomized (e.g., 17,
10, 24, 17, 24, 10, 10, 27 km∙h \[-1\], etc.) within each set for
each running condition, with the taped condition performed during set 2 and 4. The testing sequence was
therefore the following: 3 runs at each speed untaped, 3
runs at each speed taped, 3 runs at each speed untaped and
3 runs at each speed taped. To make sure that the tape
effect was consistent and reproducible across set 2 and 4,
the same length of tape was used and it was repositioned
at the same place on the player’s leg. During the 4 series
of runs, the player wore positioned between his scapulars
and at the approximate level of T2, a commerciallyavailable GPS unit (SPI HPU, GPSports, Canberra, Australia) with an embedded 100-Hz triaxial accelerometer.
The GPS unit was held securely in a manufacturer recommended GPS-vest, as previously described (Aughey,
2011). The GPS unit and imbedded accelerometer was
vertically-oriented (Z axis) when the player was standing
upright, the Y axis was orientated to forward-backward
horizontal movement and the X axis was orientated to the
left-right lateral deviations. Similar accelerometer data
have shown good reliability when collected on football
players during football-specific training exercise (Boyd et
al., 2011).

**Figure 1. Achilles tendon taped to create the stride imbal-**

**ance.**

_Methodology._ CT and FT were computed as previously described from both treadmill (based the vertical

699

ground reaction force signal) (Morin et al., 2005) and
accelerometers (Gaudino et al., 2013) (Athletic Data Innovations, using the magnitude vector, Figure 2) data by
two independent scientists. Both scientists were blind to
the data obtained with the other device; the data were then
pooled by a third scientist who calculated vertical stiffness for both devices using Morin et al.’s equation (Morin
et al., 2005). Briefly, this equation is based on a sinewave modeling of the vertical ground reaction force during the support phase, and uses CT, FT and subject’s
body mass as computation inputs. Vertical reaction force
data obtained with the treadmill were sampled at 1000 Hz
during a 30-s period. For each run, after appropriate filtering (Butterworth-type 30 Hz low-pass filter, based on
pilot residual analyses), instantaneous values of vertical
ground reaction force were analyzed for 10 consecutive
steps. CT and FT were determined for each step using a
30 N threshold (Figure 2, once strides were stabilized, i.e.,
generally after the initial 10-12 steps). The accelerometerderived data was processed using a fourth-order Butterworth filter (20-Hz cut-off, sampling frequency 100 Hz)
aimed at reducing signal noise. Detection algorithms
(Athletic Data Innovations) were used to recognize foot
strikes based on the magnitude vector and the relationship
between the Y and Z components of the accelerometer
data. Due to the alignment of the unit on the subject’s
upper back, the axial components of the accelerometer
data are not truly vertical or frontal, but change with the
varying orientation of the subject’s torso. The side of the
foot strike (left vs. right) was assigned using a two-pass
algorithm (Athletic Data Innovations) utilizing primarily
the X component of the accelerometer. CT and FT were
calculated using the filtered accelerometer-derived data
by determining the time between the ‘foot strike start
positon’ and the ‘foot strike end position’ (CT) using the
previously mentioned detection algorithm. Consequently,
the time between the ‘foot strike end position’ and the
next ‘foot strike start position’ were used to determine FT.
To increase the sample size and allow a correlation analysis with sufficient statically power representative of the
wide range of steps encountered during training and
matches, the data from the 18 runs were then pooled together for analysis (3 speeds x 6 runs x 10 steps = 180
steps).

**Statistical analysis**
The agreement between treadmill (criterion measure) and
accelerometer-derived data was examined using a specifically-designed spreadsheet (Hopkins, 2000), which calculated the mean bias (90% confidence limits, CL) and the
typical error of the estimate (TEE, 90% CL) both in percentage and standardized units, and Pearson correlation
coefficients (r, 90% CL). We also compared the ability of
the different systems to detect the stride imbalance using
magnitude-based inferences (Hopkins et al., 2009).
Threshold values for biases, TEE and standardized differences, were >0.2 (small), >0.6 (moderate), >1.2 (large)
and very large (>2) (Hopkins et al., 2009). Finally, the
following criteria were adopted to interpret the magnitude
of the correlation: ≤0.1, trivial; >0.1-0.3, small; >0.3-0.5,
moderate; >0.5-0.7, large; >0.7-0.9, very large; and >0.9

700

1.0, almost perfect. If the 90% CI overlapped small positive and negative values, the magnitude was deemed unclear; otherwise that magnitude was deemed to be the
observed magnitude (Hopkins et al., 2009).

**Figure 2. Accelerometer-derived magnitude vector during 10**
**successive steps, as measured for the three different running**
**speeds (untaped condition).**

**Results**

Biases were small (CT, -10.4%; 90CI: -12.3, -9.8; K 13.3%; -14.6, -11.9) and moderate (FT, -25.8%; -18.8, 27.7). The typical error of the estimate was trivial (CT:
3.9%, 3.4, 4.6), small (K: 6.3%; 5.5, 7.5) and moderate
(FT: 15.7%; 13.5,18.9), with nearly perfect (CT: r = 0.98;
90%CI 0.97, 0.99; K: 0.98; 0.97, 0.99) and large (FT:
0.68; 0.55, 0.78) correlations for treadmill vs. accelerome
ter.

The tape induced very large increase in the right left foot ∆ in CT (4.5%; 4.2, 4.9), FT (7.0%; 2.3, 11.3)
and K (10.3%; 8.6, 12.0) on the treadmill. The tape effect
observed with the accelerometer on CT (3.7%, 2.3, 5.0)
and K (6.4%, 3.8, 9.2) were also very large but of lower
magnitude than with the treadmill (∆ in the ∆ CT: -0.9%,
-2.4, 0.7 and K: -3.9%, -7.5, -0.3). The accelerometerderived tape effect on FT was unclear (0.3%, -3.7, 4.3).

**Discussion**

Assessing stride variables with accelerometers

The first result of this preliminary study was that stride
variables and vertical stiffness could be accurately estimated using 100-Hz GPS-embedded triaxial accelerometers. While the promise of such devices to detect stride
variables have already been reported (Gaudino et al.,
2013), this is to our knowledge the first time that the data
derived from a GPS-embedded tri-axial accelerometer

were directly compared with a gold standard (i.e., vertical
ground reaction force obtained from an instrumented
treadmill) over several steps. Compared with the criterion
measures obtained with the treadmill, the biases and typical errors were of small-to-moderate amplitude only, with
nearly perfect to large correlations between the two technologies. Considering both the practical (outdoor use of a
portable and individual device vs. lab-based and stationary device) and economical aspects of the accelerometer
technology (instrumented treadmill or force plates systems cost up to 100 times more than accelerometers), and
since CT and K are two important determinants of highintensity running performance (Girard et al., 2011; Morin
et al., 2006), our preliminary results open new perspectives for the field monitoring of neuromuscular fatigue.
The smaller relative bias and greater CV reported for FT
compared with CT may not reflect real differences in
validity and reliability _per se_ given the strong interdependency of both measures (i.e., when the athlete’s foot
is not in contact with the ground it could only be in the
air). This is likely the result of the smaller absolute values
of FT (0.10-0.15 s) compared with CT (0.15-0.25 s),
which artificial increases the magnitude of the bias and
TEE values when expressed in percentage.

The second important finding of the present study
was the ability of the GPS-embedded accelerometer to
detect stride imbalances. While the tape-related imbalance
could be detected via the analysis of all the treadmill
variables (right-left differences in CT, FT and K were all
very large), the imbalance was only apparent on CT and
K measures with the GPS-embedded accelerometer, and
of a smaller magnitude than with the treadmill. Despite a
slightly lower sensitivity to the stride imbalance, the accelerometer-derived data are likely relevant enough to
detect running asymmetries in the field, which highlights
the interest of such devices for the monitoring of potential
lower-limb strength asymmetries in athletes.

A limitation of the present preliminary study however is that all measures were collected on a single subject; whether similar results would be reported in various
individuals with different anthropometrical attributes,
stride patterns and running experiences still remains to be
examined.

**Practical applications**
Today, almost all GPS systems, whatever the brand, include high-frequency tri-axial accelerometers in their
individual units. Both manufacturer-provided (e.g., Team
AMS for GPSports, Sprint for Catapult) and custom-made
softwares (e.g., Athletic Data Innovations) allow automated and rapid stride analysis, which increases both the
quantity and the quality of the data collected on each
player. Since contact time and vertical stiffness are two
important determinants of high-intensity running perfor

Buchheit et al.

mance (Morin et al., 2006, Girard et al., 2011), and given
the possible prognostic of lower-limb strength asymmetries (Fousekis et al., 2011), our results open new perspectives for the field monitoring of neuromuscular fatigue.
Another very important aspect of the present technology
is that accelerometers can be used indoor (i.e., no GPS
signal needed), which in fine allows their use for almost
every type of run-based type of sports (e.g., basketball,
handball).

**Conclusion**

Present data highlight the potential of GPS-embedded triaxial accelerometers to assess contact time and vertical
stiffness during ground running. Since these two latter
variables are important determinants of high-intensity
running performance (Morin et al., 2006, Girard et al.,
2011), and since lower-limb strength imbalances may be
related to a higher injury risk (Fousekis et al., 2011), our
preliminary results open new perspective for the field
monitoring of neuromuscular fatigue and performance in
run-based sports.

**Acknowledgements**
The authors thank Franck Brocherie, Olivier Girard and Sean O’Connor
for their help with data collection.

**References**

Aughey, R.J. (2011) Applications of GPS technologies to field sports.
_International Journal of Sports Physiology and Performance_ **6**,
295-310.
Barrett, S., Midgley, A. and Lovell, R. (2014) PlayerLoad: reliability,
convergent validity, and influence of unit position during
treadmill running. _International Journal of Sports Physiology_
_and Performance_ **9**, 945-952.
Boyd, L.J., Ball, K. and Aughey, R.J. (2011) The reliability of MinimaxX accelerometers for measuring physical activity in Australian football. _International Journal of Sports Physiology and_
_Performance_ **6**, 311-321.
Carling, C. (2013) Interpreting physical performance in professional
soccer match-play: should we be more pragmatic in our approach? _Sports Medicine_ **43**, 655-663.
Cormack, S.J., Mooney, M.G., Morgan, W. and McGuigan, M.R. (2013)
Influence of neuromuscular fatigue on accelerometer load in
elite Australian football players. _International Journal of Sports_
_Physiology and Performance_ **8**, 373-378.
Fousekis, K., Tsepis, E., Poulmedis, P., Athanasopoulos S. and Vagenas,
G. (2011) Intrinsic risk factors of non-contact quadriceps and
hamstring strains in soccer: a prospective study of 100 professional players. _British Journal of Sports Medicince_ **45**, 709714.

Gaudino, P., Gaudino, C., Alberti, G.and Minetti, A.E. (2013) Biomechanics and predicted energetics of sprinting on sand: hints for
soccer training. _Journal of Science andMedicince in Sport_ **16**,
271-275.
Girard, O., Micallef, J.P. and Millet, G.P. (2011) Changes in springmass model characteristics during repeated running sprints. _Eu-_
_ropean Journal of Applied Physiology_ **111**, 125-134.
Hopkins, W. (2000) Analysis of validity by linear regression (Excel
spreadsheet). In: _A new view of statistics._ sportsci.org: Internet
Society for Sport Science. Available form URL:
<http://sportsci.org/resource/stats/xvalid.xls>.
Hopkins, W.G., Marshall, S.W., Batterham, A.M. and Hanin, J. (2009)
Progressive statistics for studies in sports medicine and exercise
science. _Medicince and Science in Sports and Exercise_ **41**, 313.

Morin, J.B., Dalleau, G., Kyrolainen, H., Jeannin, T.and Belli, A.
(2005). A simple method for measuring stiffness during running. _Journal of Applied Biomechanice_ **21**, 167-180.

701

Morin, J.B., Jeannin, T., Chevallier, B. and Belli, A. (2006) Spring-mass
model characteristics during sprint running: correlation with
performance and fatigue-induced changes. _International Jour-_
_nal of Sports Medicine_ **27**, 158-165.

**AUTHOR BIOGRAPHY**

| Col1 | MartinBUCHHEIT<br>Employment<br>Sport Science Department Myorobie<br>,<br>Association Montvalezan France;<br>,,<br>Performance Department Paris Saint-<br>,<br>Germain Football Club Saint-Germain-en-<br>,<br>Laye France;<br>,<br>Institute of Sport Exercise and Active<br>,<br>Living College of Sport and Exercise<br>,<br>Science Victoria University Melbourne<br>,,,<br>Australia<br>Degree<br>PhD MSc Strength & Conditioning and<br>,,<br>Satistics<br>Researchinterest<br>Trainingmonitoringandprorgramming<br>E -mail: mb@martin-buchheit .net |
| ---- |   |
|      | **Andrew GRAY**<br>**Employment**<br>Cronulla Sharks Rugby League Football<br>Club, NSW, Australia<br>Athletic Data Innovations, Sydney, NSW,<br>Australia<br>**Degree**<br>MSc,<br>Strength<br>& <br>Conditioning,<br>Physiotherapy<br>**Research interest**<br>Training monitoring<br>**E-mail:**<br>athleticdatainnova-<br><tions@bigpond.com>                                                                                                                                                                                                          |
|      | **Jean-Benoit MORIN**<br>**Employment**<br>Full Professor, University of Nice Sophia<br>Antipolis, Faculty of Sport Sciences, France<br>**Degree**<br>PhD<br>**Research interest**<br>Sports Performance, Running Mechanics,<br>Sprint Mechanics, Injury Prevention<br>**E-mail:** <jean-benoit.morin@unice.fr>                                                                                                                                                                                                                                            |

 **Martin Buchheit**
Sport Science Department, Myorobie Association, 73700
Montvalezan, France
